@@ -1,5 +1,5 @@
-use crate::linear_algebra::mat::Mat3;
-use crate::linear_algebra::vector::Vec3;
+use super::mat::Mat3;
+use super::vector::Vec3;
 
 pub fn dot(a: &Mat3, v: &Vec3) -> Vec3 {
     Vec3 {
